//--------------------------------------------------------------------
//  Sample C Code for the ADCINCVR
//  Continuously sample and call a user function with the data.
//
//--------------------------------------------------------------------
//**********************************************************************//
//	Port0_7 is analog input from potentiometer							//
//	Port0_0 is a digital input to cut off the motor						//
//	Port0_4 is digital output for the direction							//
//	Port0_5 is digital output for motor run								//
//  DAC removed because Direction is pure digital						//
//**********************************************************************//

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include "m8c.h"
#include "string.h"		// PSoC string function definitions
#include "stdlib.h"		// PSoC standard library function definitions

#define POWER 		PRT0DR
#define CW 			0x01
#define CCW 		0xFE
#define forever		1
#define DeadBand	40	// When ADC in DeadBand switch off motor
#define BitMask(BitNumber) (0x01 << BitNumber)

void InitializeHardware(void)
{
    M8C_EnableGInt;                     // Enable global interrupts

	ADCINCVR_Start(ADCINCVR_HIGHPOWER); // Turn on Analog section
    ADCINCVR_SetResolution(8);			// Set resolution to 8 Bits 
    ADCINCVR_GetSamples(0);             // Start ADC to read continuously
    //PGA_SetGain(PGA_G1_00);
    PGA_Start(PGA_HIGHPOWER);			//The PGA reference is set to GND
	PRT0DR &= ~BitMask(0);				// Clear Bit 0, it is pull down, so we have a low level.
	DirectionPin_Start();				// Direction now set to 0
	RunPin_Start();						// Motor Stop
}

void Wait(void)
{
	// Do Nothing
	// just for better readability
}

void main(void)
{
static unsigned int iData;
	InitializeHardware();
	while(forever)						// Main loop. Executed as long as there is power
    {
		if (POWER & CW )				// When High level applied to Port0_0
		{
				
			while(ADCINCVR_fIsDataAvailable() == 0) Wait(); // Wait for ADC-data to be ready.

			iData = ADCINCVR_iGetData();    // Get Data

			ADCINCVR_ClearFlag();
			
			if(iData < (128 - DeadBand))		DirectionPin_On();					// Set direction
			if(iData > (128 + DeadBand))		DirectionPin_Off();
			RunPin_Switch((iData < (128 - DeadBand)) | (iData > (128 + DeadBand)));	// Set motor running
		}
	}
}

